[jboss-cvs] JBossAS SVN: r105261 - in projects/jboss-deployers/trunk: deployers-impl and 16 other directories.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Wed May 26 11:44:13 EDT 2010


Author: alesj
Date: 2010-05-26 11:44:09 -0400 (Wed, 26 May 2010)
New Revision: 105261

Added:
   projects/jboss-deployers/trunk/deployers-impl/src/main/java/org/jboss/deployers/plugins/annotations/AbstractAnnotationDeployer.java
Removed:
   projects/jboss-deployers/trunk/deployers-impl/src/test/java/org/jboss/test/deployers/annotations/
   projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/deployer/helpers/AbstractAnnotationDeployer.java
   projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/annotations/JavassistAnnotationRepositoryDeployer.java
   projects/jboss-deployers/trunk/deployers-vfs/src/test/java/org/jboss/test/deployers/vfs/annotations/
Modified:
   projects/jboss-deployers/trunk/deployers-impl/pom.xml
   projects/jboss-deployers/trunk/deployers-impl/src/main/java/org/jboss/deployers/plugins/annotations/GenericAnnotationDeployer.java
   projects/jboss-deployers/trunk/deployers-impl/src/test/java/org/jboss/test/deployers/DeployersImplTestSuite.java
   projects/jboss-deployers/trunk/deployers-spi/pom.xml
   projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/annotations/FilterablePathEntry.java
   projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/annotations/PathEntryMetaData.java
   projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/annotations/PathMetaData.java
   projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/annotations/ScanningMetaData.java
   projects/jboss-deployers/trunk/deployers-vfs-spi/pom.xml
   projects/jboss-deployers/trunk/deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure/CandidateAnnotationsCallback.java
   projects/jboss-deployers/trunk/deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure/helpers/AbstractStructureDeployer.java
   projects/jboss-deployers/trunk/deployers-vfs/pom.xml
   projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/deployer/kernel/BeanScanningDeployer.java
   projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/annotations/AnnotationRepositoryDeployer.java
   projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/annotations/FilteredAnnotationRepositoryDeployer.java
   projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/structure/AbstractVFSStructureDeployer.java
   projects/jboss-deployers/trunk/deployers-vfs/src/test/java/org/jboss/test/deployers/DeployersVFSTestSuite.java
   projects/jboss-deployers/trunk/deployers-vfs/src/test/java/org/jboss/test/deployers/vfs/deployer/bean/test/BeanScanningUnitTestCase.java
   projects/jboss-deployers/trunk/deployers-vfs/src/test/java/org/jboss/test/deployers/vfs/structure/ear/support/MockEarStructureDeployer.java
   projects/jboss-deployers/trunk/pom.xml
Log:
[JBDEPLOY-262]; remove mcann, introduce new scanning lib.


Modified: projects/jboss-deployers/trunk/deployers-impl/pom.xml
===================================================================
--- projects/jboss-deployers/trunk/deployers-impl/pom.xml	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-impl/pom.xml	2010-05-26 15:44:09 UTC (rev 105261)
@@ -151,10 +151,14 @@
       </exclusions>
     </dependency>
     <dependency>
-      <groupId>org.jboss.mcann</groupId>
-      <artifactId>mcann-core</artifactId>
+      <groupId>org.jboss.scanning</groupId>
+      <artifactId>scanning-plugins</artifactId>
       <exclusions>
         <exclusion>
+          <groupId>org.jboss.deployers</groupId>
+          <artifactId>jboss-deployers-spi</artifactId>
+        </exclusion>
+        <exclusion>
           <groupId>org.jboss.vfs</groupId>
           <artifactId>jboss-vfs</artifactId>
         </exclusion>
@@ -182,6 +186,34 @@
           <groupId>org.jboss.cl</groupId>
           <artifactId>jboss-classloading</artifactId>
         </exclusion>
+        <exclusion>
+          <groupId>org.jboss.cl</groupId>
+          <artifactId>jboss-classloading-vfs</artifactId>
+        </exclusion>
+        <exclusion>
+            <groupId>org.jboss.weld.integration</groupId>
+            <artifactId>weld-jboss-int-deployer</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.mc-int</groupId>
+            <artifactId>jboss-mc-int-servlet</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>javax.faces</groupId>
+            <artifactId>jsf-api</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>javax.faces</groupId>
+            <artifactId>jsf-impl</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>javassist</groupId>
+            <artifactId>javassist</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.hibernate</groupId>
+            <artifactId>hibernate-entitymanager</artifactId>
+          </exclusion>
       </exclusions>
     </dependency>
     <dependency>

Added: projects/jboss-deployers/trunk/deployers-impl/src/main/java/org/jboss/deployers/plugins/annotations/AbstractAnnotationDeployer.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-impl/src/main/java/org/jboss/deployers/plugins/annotations/AbstractAnnotationDeployer.java	                        (rev 0)
+++ projects/jboss-deployers/trunk/deployers-impl/src/main/java/org/jboss/deployers/plugins/annotations/AbstractAnnotationDeployer.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -0,0 +1,82 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2010, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+
+package org.jboss.deployers.plugins.annotations;
+
+import java.lang.annotation.Annotation;
+import java.util.Set;
+
+import org.jboss.deployers.spi.DeploymentException;
+import org.jboss.deployers.spi.deployer.helpers.AbstractSimpleRealDeployer;
+import org.jboss.deployers.spi.deployer.helpers.AnnotationProcessor;
+import org.jboss.deployers.structure.spi.DeploymentUnit;
+import org.jboss.scanning.annotations.spi.AnnotationRepository;
+import org.jboss.scanning.annotations.spi.Element;
+
+/**
+ * AbstractComponentDeployer.
+ *
+ * @author <a href="ales.justin at jboss.com">Ales Justin</a>
+ */
+public class AbstractAnnotationDeployer extends AbstractSimpleRealDeployer<AnnotationRepository>
+{
+   /** The annotation processors */
+   private AnnotationProcessor<?, ?>[] processors;
+
+   public AbstractAnnotationDeployer(AnnotationProcessor<?, ?>... processors)
+   {
+      super(AnnotationRepository.class);
+      if (processors != null && processors.length > 0)
+      {
+         this.processors = processors;
+         for (AnnotationProcessor<?, ?> processor : processors)
+         {
+            addInput(processor.getAnnotation());
+            addOutput(processor.getOutput());
+         }
+      }
+      else
+         throw new IllegalArgumentException("Null or empty processors.");
+   }
+
+   @SuppressWarnings("unchecked")
+   public void deploy(DeploymentUnit unit, AnnotationRepository deployment) throws DeploymentException
+   {
+      for (AnnotationProcessor processor : processors)
+      {
+         String attachmentName = processor.getAnnotation().getName();
+         Object annotationAttachment = unit.getAttachment(attachmentName);
+         Object metadata = processor.createMetaData(annotationAttachment);
+         if (metadata != null)
+            unit.addAttachment(attachmentName, metadata);
+
+         Set<Element<Annotation, Class>> elements = deployment.classIsAnnotatedWith(processor.getAnnotation());
+         for (Element<Annotation, Class> elt : elements)
+         {
+            Class<?> clazz = elt.getOwner();
+            metadata = processor.createMetaDataFromClass(clazz);
+            if (metadata != null)
+               unit.addAttachment(attachmentName + "#" + clazz.getName(), metadata);
+         }
+      }
+   }
+}
\ No newline at end of file

Modified: projects/jboss-deployers/trunk/deployers-impl/src/main/java/org/jboss/deployers/plugins/annotations/GenericAnnotationDeployer.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-impl/src/main/java/org/jboss/deployers/plugins/annotations/GenericAnnotationDeployer.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-impl/src/main/java/org/jboss/deployers/plugins/annotations/GenericAnnotationDeployer.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -26,10 +26,10 @@
 import org.jboss.deployers.spi.deployer.DeploymentStages;
 import org.jboss.deployers.spi.deployer.helpers.AbstractSimpleRealDeployer;
 import org.jboss.deployers.structure.spi.DeploymentUnit;
-import org.jboss.mcann.AnnotationRepository;
-import org.jboss.mcann.repository.Configuration;
-import org.jboss.mcann.scanner.DefaultAnnotationScanner;
-import org.jboss.mcann.scanner.ModuleAnnotationScanner;
+import org.jboss.scanning.annotations.plugins.AnnotationsScanningPlugin;
+import org.jboss.scanning.annotations.spi.AnnotationRepository;
+import org.jboss.scanning.plugins.DeploymentUnitScanner;
+import org.jboss.scanning.spi.helpers.AbstractScanner;
 
 /**
  * Generic annotation scanner deployer.
@@ -38,8 +38,6 @@
  */
 public class GenericAnnotationDeployer extends AbstractSimpleRealDeployer<Module>
 {
-   private Configuration configuration;
-
    public GenericAnnotationDeployer()
    {
       super(Module.class);
@@ -51,11 +49,13 @@
    {
       try
       {
-         DefaultAnnotationScanner scanner = new ModuleAnnotationScanner(deployment);
-         if (configuration != null)
-            scanner.setConfiguration(configuration);
-         
-         AnnotationRepository repository = scanner.scan(unit.getClassLoader());
+         AbstractScanner scanner = new DeploymentUnitScanner(unit);
+         AnnotationsScanningPlugin plugin = new AnnotationsScanningPlugin(unit.getClassLoader());
+         scanner.addPlugin(plugin);
+
+         scanner.scan();
+
+         AnnotationRepository repository = unit.getAttachment(plugin.getAttachmentKey(), AnnotationRepository.class);
          unit.addAttachment(AnnotationRepository.class, repository);
       }
       catch (Exception e)
@@ -63,14 +63,4 @@
          throw DeploymentException.rethrowAsDeploymentException("Cannot create AR", e);
       }
    }
-
-   /**
-    * Set configuration.
-    *
-    * @param configuration the configuration creator
-    */
-   public void setConfiguration(Configuration configuration)
-   {
-      this.configuration = configuration;
-   }
 }

Modified: projects/jboss-deployers/trunk/deployers-impl/src/test/java/org/jboss/test/deployers/DeployersImplTestSuite.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-impl/src/test/java/org/jboss/test/deployers/DeployersImplTestSuite.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-impl/src/test/java/org/jboss/test/deployers/DeployersImplTestSuite.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -21,10 +21,6 @@
 */
 package org.jboss.test.deployers;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-import junit.textui.TestRunner;
-import org.jboss.test.deployers.annotations.DeployersAnnotationsTestSuite;
 import org.jboss.test.deployers.classloading.DeployersClassLoadingTestSuite;
 import org.jboss.test.deployers.deployer.DeployersDeployerTestSuite;
 import org.jboss.test.deployers.exceptions.DeployersExceptionsTestSuite;
@@ -32,6 +28,10 @@
 import org.jboss.test.deployers.managed.DeployersManagedTestSuite;
 import org.jboss.test.deployers.scope.DeployersScopeTestSuite;
 
+import junit.framework.Test;
+import junit.framework.TestSuite;
+import junit.textui.TestRunner;
+
 /**
  * Deployers Impl Test Suite.
  * 
@@ -55,7 +55,6 @@
       suite.addTest(DeployersClassLoadingTestSuite.suite());
       suite.addTest(DeployersScopeTestSuite.suite());
       suite.addTest(DeployersMainTestSuite.suite());
-      suite.addTest(DeployersAnnotationsTestSuite.suite());
       suite.addTest(DeployersExceptionsTestSuite.suite());
 
       return suite;

Modified: projects/jboss-deployers/trunk/deployers-spi/pom.xml
===================================================================
--- projects/jboss-deployers/trunk/deployers-spi/pom.xml	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-spi/pom.xml	2010-05-26 15:44:09 UTC (rev 105261)
@@ -21,39 +21,27 @@
       <groupId>org.jboss</groupId>
       <artifactId>jbossxb</artifactId>
     </dependency>
-    <dependency>
-      <groupId>org.jboss.mcann</groupId>
-      <artifactId>mcann-core</artifactId>
-      <exclusions>
-        <exclusion>
-          <groupId>org.jboss.vfs</groupId>
-          <artifactId>jboss-vfs</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss</groupId>
-          <artifactId>jboss-reflect</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.man</groupId>
-          <artifactId>jboss-managed</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.man</groupId>
-          <artifactId>jboss-metatype</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.microcontainer</groupId>
-          <artifactId>jboss-kernel</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.kernel</groupId>
-          <artifactId>jboss-kernel</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.cl</groupId>
-          <artifactId>jboss-classloading</artifactId>
-        </exclusion>
-      </exclusions>
-    </dependency>
+      <dependency>
+        <groupId>org.jboss.cl</groupId>
+        <artifactId>jboss-classloader</artifactId>
+        <exclusions>
+          <exclusion>
+            <groupId>org.jboss</groupId>
+            <artifactId>jboss-common-core</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.logging</groupId>
+            <artifactId>jboss-logging-spi</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.microcontainer</groupId>
+            <artifactId>jboss-dependency</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.kernel</groupId>
+            <artifactId>jboss-dependency</artifactId>
+          </exclusion>
+        </exclusions>
+      </dependency>
   </dependencies>
 </project>
\ No newline at end of file

Modified: projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/annotations/FilterablePathEntry.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/annotations/FilterablePathEntry.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/annotations/FilterablePathEntry.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -28,6 +28,7 @@
  *
  * @author <a href="mailto:ales.justin at jboss.com">Ales Justin</a>
  */
+ at Deprecated
 public interface FilterablePathEntry
 {
    /**

Modified: projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/annotations/PathEntryMetaData.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/annotations/PathEntryMetaData.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/annotations/PathEntryMetaData.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -26,6 +26,7 @@
  *
  * @author <a href="mailto:ales.justin at jboss.com">Ales Justin</a>
  */
+ at Deprecated
 public interface PathEntryMetaData
 {
    /**

Modified: projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/annotations/PathMetaData.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/annotations/PathMetaData.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/annotations/PathMetaData.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -28,6 +28,7 @@
  *
  * @author <a href="mailto:ales.justin at jboss.com">Ales Justin</a>
  */
+ at Deprecated
 public interface PathMetaData
 {
    /**

Modified: projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/annotations/ScanningMetaData.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/annotations/ScanningMetaData.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/annotations/ScanningMetaData.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -28,6 +28,7 @@
  *
  * @author <a href="mailto:ales.justin at jboss.com">Ales Justin</a>
  */
+ at Deprecated
 public interface ScanningMetaData
 {
    /**

Deleted: projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/deployer/helpers/AbstractAnnotationDeployer.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/deployer/helpers/AbstractAnnotationDeployer.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-spi/src/main/java/org/jboss/deployers/spi/deployer/helpers/AbstractAnnotationDeployer.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -1,79 +0,0 @@
-/*
-* JBoss, Home of Professional Open Source
-* Copyright 2006, JBoss Inc., and individual contributors as indicated
-* by the @authors tag. See the copyright.txt in the distribution for a
-* full listing of individual contributors.
-*
-* This is free software; you can redistribute it and/or modify it
-* under the terms of the GNU Lesser General Public License as
-* published by the Free Software Foundation; either version 2.1 of
-* the License, or (at your option) any later version.
-*
-* This software is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-* Lesser General Public License for more details.
-*
-* You should have received a copy of the GNU Lesser General Public
-* License along with this software; if not, write to the Free
-* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-*/
-package org.jboss.deployers.spi.deployer.helpers;
-
-import java.lang.annotation.Annotation;
-import java.util.Set;
-
-import org.jboss.deployers.spi.DeploymentException;
-import org.jboss.deployers.structure.spi.DeploymentUnit;
-import org.jboss.mcann.AnnotationRepository;
-import org.jboss.mcann.Element;
-
-/**
- * AbstractComponentDeployer.
- *
- * @author <a href="ales.justin at jboss.com">Ales Justin</a>
- */
-public class AbstractAnnotationDeployer extends AbstractSimpleRealDeployer<AnnotationRepository>
-{
-   /** The annotation processors */
-   private AnnotationProcessor<?, ?>[] processors;
-
-   public AbstractAnnotationDeployer(AnnotationProcessor<?, ?>... processors)
-   {
-      super(AnnotationRepository.class);
-      if (processors != null && processors.length > 0)
-      {
-         this.processors = processors;
-         for (AnnotationProcessor<?, ?> processor : processors)
-         {
-            addInput(processor.getAnnotation());
-            addOutput(processor.getOutput());
-         }
-      }
-      else
-         throw new IllegalArgumentException("Null or empty processors.");
-   }
-
-   @SuppressWarnings("unchecked")
-   public void deploy(DeploymentUnit unit, AnnotationRepository deployment) throws DeploymentException
-   {
-      for (AnnotationProcessor processor : processors)
-      {
-         String attachmentName = processor.getAnnotation().getName();
-         Object annotationAttachment = unit.getAttachment(attachmentName);
-         Object metadata = processor.createMetaData(annotationAttachment);
-         if (metadata != null)
-            unit.addAttachment(attachmentName, metadata);
-
-         Set<Element<Annotation, Class>> elements = deployment.classIsAnnotatedWith(processor.getAnnotation());
-         for (Element<Annotation, Class> elt : elements)
-         {
-            Class<?> clazz = elt.getOwner();
-            metadata = processor.createMetaDataFromClass(clazz);
-            if (metadata != null)
-               unit.addAttachment(attachmentName + "#" + clazz.getName(), metadata);
-         }
-      }
-   }
-}
\ No newline at end of file

Modified: projects/jboss-deployers/trunk/deployers-vfs/pom.xml
===================================================================
--- projects/jboss-deployers/trunk/deployers-vfs/pom.xml	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-vfs/pom.xml	2010-05-26 15:44:09 UTC (rev 105261)
@@ -45,41 +45,73 @@
       <groupId>org.jboss.kernel</groupId>
 	    <artifactId>jboss-kernel</artifactId>
 	 </dependency>
+      <dependency>
+        <groupId>org.jboss.scanning</groupId>
+        <artifactId>scanning-plugins</artifactId>
+        <exclusions>
+          <exclusion>
+            <groupId>org.jboss.deployers</groupId>
+            <artifactId>jboss-deployers-spi</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.vfs</groupId>
+            <artifactId>jboss-vfs</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss</groupId>
+            <artifactId>jboss-reflect</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.man</groupId>
+            <artifactId>jboss-managed</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.man</groupId>
+            <artifactId>jboss-metatype</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.microcontainer</groupId>
+            <artifactId>jboss-kernel</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.kernel</groupId>
+            <artifactId>jboss-kernel</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.cl</groupId>
+            <artifactId>jboss-classloading</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.cl</groupId>
+            <artifactId>jboss-classloading-vfs</artifactId>
+          </exclusion>
+          <exclusion>
+              <groupId>org.jboss.weld.integration</groupId>
+              <artifactId>weld-jboss-int-deployer</artifactId>
+            </exclusion>
+            <exclusion>
+              <groupId>org.jboss.mc-int</groupId>
+              <artifactId>jboss-mc-int-servlet</artifactId>
+            </exclusion>
+            <exclusion>
+              <groupId>javax.faces</groupId>
+              <artifactId>jsf-api</artifactId>
+            </exclusion>
+            <exclusion>
+              <groupId>javax.faces</groupId>
+              <artifactId>jsf-impl</artifactId>
+            </exclusion>
+            <exclusion>
+              <groupId>javassist</groupId>
+              <artifactId>javassist</artifactId>
+            </exclusion>
+            <exclusion>
+              <groupId>org.hibernate</groupId>
+              <artifactId>hibernate-entitymanager</artifactId>
+            </exclusion>
+        </exclusions>
+      </dependency>
     <dependency>
-      <groupId>org.jboss.mcann</groupId>
-      <artifactId>mcann-core</artifactId>
-      <exclusions>
-        <exclusion>
-          <groupId>org.jboss.vfs</groupId>
-          <artifactId>jboss-vfs</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss</groupId>
-          <artifactId>jboss-reflect</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.man</groupId>
-          <artifactId>jboss-managed</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.man</groupId>
-          <artifactId>jboss-metatype</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.microcontainer</groupId>
-          <artifactId>jboss-kernel</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.kernel</groupId>
-          <artifactId>jboss-kernel</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.cl</groupId>
-          <artifactId>jboss-classloading</artifactId>
-        </exclusion>
-      </exclusions>
-    </dependency>
-    <dependency>
       <groupId>org.jboss.cl</groupId>
       <artifactId>jboss-classloading-vfs</artifactId>
       <exclusions>
@@ -183,40 +215,6 @@
         </exclusion>
       </exclusions>
     </dependency>
-    <dependency>
-      <groupId>org.jboss.mcann</groupId>
-      <artifactId>mcann-core</artifactId>
-      <exclusions>
-        <exclusion>
-          <groupId>org.jboss.vfs</groupId>
-          <artifactId>jboss-vfs</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss</groupId>
-          <artifactId>jboss-reflect</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.man</groupId>
-          <artifactId>jboss-managed</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.man</groupId>
-          <artifactId>jboss-metatype</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.microcontainer</groupId>
-          <artifactId>jboss-kernel</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.kernel</groupId>
-          <artifactId>jboss-kernel</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.cl</groupId>
-          <artifactId>jboss-classloading</artifactId>
-        </exclusion>
-      </exclusions>
-    </dependency>
     <!-- Test dependencies -->
     <dependency>
       <groupId>org.jboss.deployers</groupId>

Modified: projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/deployer/kernel/BeanScanningDeployer.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/deployer/kernel/BeanScanningDeployer.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/deployer/kernel/BeanScanningDeployer.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -32,7 +32,7 @@
 import org.jboss.beans.metadata.spi.BeanMetaData;
 import org.jboss.beans.metadata.spi.builder.BeanMetaDataBuilder;
 import org.jboss.beans.metadata.spi.factory.GenericBeanFactoryMetaData;
-import org.jboss.deployers.spi.deployer.helpers.AbstractAnnotationDeployer;
+import org.jboss.deployers.plugins.annotations.AbstractAnnotationDeployer;
 import org.jboss.deployers.spi.deployer.helpers.AbstractAnnotationProcessor;
 
 /**

Modified: projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/annotations/AnnotationRepositoryDeployer.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/annotations/FilteredAnnotationRepositoryDeployer.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/annotations/FilteredAnnotationRepositoryDeployer.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -21,12 +21,11 @@
 */
 package org.jboss.deployers.vfs.plugins.annotations;
 
+import org.jboss.classloading.spi.visitor.ClassFilter;
 import org.jboss.classloading.spi.visitor.ResourceFilter;
 import org.jboss.deployers.structure.spi.DeploymentUnit;
 import org.jboss.deployers.vfs.spi.structure.VFSDeploymentUnit;
-import org.jboss.mcann.repository.AbstractSettings;
-import org.jboss.mcann.repository.AbstractConfiguration;
-import org.jboss.mcann.scanner.DefaultAnnotationScanner;
+import org.jboss.scanning.annotations.plugins.AnnotationsScanningPlugin;
 
 /**
  * Filtered annotation environment deployer.
@@ -37,9 +36,10 @@
  *
  * @author <a href="mailto:ales.justin at jboss.com">Ales Justin</a>
  */
+ at Deprecated
 public class FilteredAnnotationRepositoryDeployer extends AnnotationRepositoryDeployer
 {
-   private ResourceFilter resourceFilter;
+   private ResourceFilter resourceFilter = ClassFilter.INSTANCE;
    private ResourceFilter recurseFilter;
 
    public FilteredAnnotationRepositoryDeployer()
@@ -68,30 +68,22 @@
    }
 
    @Override
-   protected AbstractConfiguration createConfiguration(VFSDeploymentUnit unit)
+   protected AnnotationsScanningPlugin createPlugin(final VFSDeploymentUnit unit)
    {
-      return getAttachment(unit, AbstractConfiguration.class, null, super.createConfiguration(unit)); 
-   }
+      return new AnnotationsScanningPlugin(unit.getClassLoader())
+      {
+         @Override
+         public ResourceFilter getFilter()
+         {
+            return getAttachment(unit, ResourceFilter.class, "resource", resourceFilter);
+         }
 
-   /**
-    * We look for filter attachments:
-    * * org.jboss.classloading.spi.visitor.ResourceFilter.resource - plain resource filter
-    * * org.jboss.classloading.spi.visitor.ResourceFilter.recurse  - recurse resource filter
-    *
-    * @param unit the deployment unit
-    * @param scanner the annotation scanner
-    * @param settings the settings
-    */
-   @Override
-   protected void configureScanner(VFSDeploymentUnit unit, DefaultAnnotationScanner scanner, AbstractSettings settings)
-   {
-      super.configureScanner(unit, scanner, settings);
-
-      ResourceFilter filter = getAttachment(unit, ResourceFilter.class, "resource", resourceFilter);
-      settings.setResourceFilter(filter);
-
-      ResourceFilter recurse = getAttachment(unit, ResourceFilter.class, "recurse", recurseFilter);
-      scanner.setRecurseFilter(recurse);
+         @Override
+         public ResourceFilter getRecurseFilter()
+         {
+            return getAttachment(unit, ResourceFilter.class, "recurse", recurseFilter);
+         }
+      };
    }
 
    /**

Deleted: projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/annotations/JavassistAnnotationRepositoryDeployer.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/annotations/JavassistAnnotationRepositoryDeployer.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/annotations/JavassistAnnotationRepositoryDeployer.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -1,40 +0,0 @@
-/*
-* JBoss, Home of Professional Open Source
-* Copyright 2006, JBoss Inc., and individual contributors as indicated
-* by the @authors tag. See the copyright.txt in the distribution for a
-* full listing of individual contributors.
-*
-* This is free software; you can redistribute it and/or modify it
-* under the terms of the GNU Lesser General Public License as
-* published by the Free Software Foundation; either version 2.1 of
-* the License, or (at your option) any later version.
-*
-* This software is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-* Lesser General Public License for more details.
-*
-* You should have received a copy of the GNU Lesser General Public
-* License along with this software; if not, write to the Free
-* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-*/
-package org.jboss.deployers.vfs.plugins.annotations;
-
-import org.jboss.mcann.repository.AbstractConfiguration;
-import org.jboss.mcann.repository.javassist.JavassistConfiguration;
-import org.jboss.deployers.vfs.spi.structure.VFSDeploymentUnit;
-
-/**
- * Javassist annotation repository deployer.
- *
- * @author <a href="mailto:ales.justin at jboss.com">Ales Justin</a>
- */
-public class JavassistAnnotationRepositoryDeployer extends FilteredAnnotationRepositoryDeployer
-{
-   @Override
-   protected AbstractConfiguration createConfiguration(VFSDeploymentUnit unit)
-   {
-      return new JavassistConfiguration();
-   }
-}
\ No newline at end of file

Modified: projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/structure/AbstractVFSStructureDeployer.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/structure/AbstractVFSStructureDeployer.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/structure/AbstractVFSStructureDeployer.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -27,9 +27,9 @@
 import org.jboss.deployers.structure.spi.DeploymentResourceLoader;
 import org.jboss.deployers.structure.spi.helpers.DeploymentResourceClassLoader;
 import org.jboss.deployers.vfs.spi.structure.helpers.AbstractStructureDeployer;
-import org.jboss.mcann.AnnotationRepository;
-import org.jboss.mcann.repository.Configuration;
-import org.jboss.mcann.scanner.DefaultAnnotationScanner;
+import org.jboss.scanning.annotations.plugins.AnnotationsScanningPlugin;
+import org.jboss.scanning.annotations.spi.AnnotationRepository;
+import org.jboss.scanning.plugins.DefaultScanner;
 import org.jboss.vfs.VirtualFile;
 
 /**
@@ -42,22 +42,29 @@
    private ClassFilter included;
    private ClassFilter excluded;
    private ResourceFilter recurseFilter;
-   private Configuration configuration;
 
    protected AnnotationRepository createAnnotationRepository(VirtualFile root)
    {
       DeploymentResourceLoader loader = new VFSDeploymentResourceLoaderImpl(root);
       ClassLoader classLoader = new DeploymentResourceClassLoader(loader);
-      DefaultAnnotationScanner scanner = new DefaultAnnotationScanner();
-      scanner.setIncluded(included);
-      scanner.setExcluded(excluded);
-      scanner.setRecurseFilter(recurseFilter);
-      if (configuration != null)
-         scanner.setConfiguration(configuration);
-
       try
       {
-         return scanner.scan(classLoader, root.toURL());
+         DefaultScanner scanner = new DefaultScanner(classLoader, root.toURL());
+         AnnotationsScanningPlugin plugin = new AnnotationsScanningPlugin(classLoader)
+         {
+            @Override
+            public ResourceFilter getRecurseFilter()
+            {
+               return recurseFilter;
+            }
+         };
+         scanner.addPlugin(plugin);
+         scanner.setIncluded(included);
+         scanner.setExcluded(excluded);
+
+         scanner.scan();
+
+         return (AnnotationRepository) scanner.getHandles().get(plugin);
       }
       catch (Exception e)
       {
@@ -94,14 +101,4 @@
    {
       this.recurseFilter = recurseFilter;
    }
-
-   /**
-    * Set configuration.
-    *
-    * @param configuration the configuration
-    */
-   public void setConfiguration(Configuration configuration)
-   {
-      this.configuration = configuration;
-   }
 }

Modified: projects/jboss-deployers/trunk/deployers-vfs/src/test/java/org/jboss/test/deployers/DeployersVFSTestSuite.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-vfs/src/test/java/org/jboss/test/deployers/DeployersVFSTestSuite.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-vfs/src/test/java/org/jboss/test/deployers/DeployersVFSTestSuite.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -21,11 +21,6 @@
 */
 package org.jboss.test.deployers;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-import junit.textui.TestRunner;
-
-import org.jboss.test.deployers.vfs.annotations.AnnotationScanningTestSuite;
 import org.jboss.test.deployers.vfs.classloader.ClassLoaderTestSuite;
 import org.jboss.test.deployers.vfs.classloading.ClassLoadingTestSuite;
 import org.jboss.test.deployers.vfs.dependency.DependencyTestSuite;
@@ -48,6 +43,10 @@
 import org.jboss.test.deployers.vfs.webbeans.WebBeansTestSuite;
 import org.jboss.test.deployers.vfs.xb.JBossXBDeployersTestSuite;
 
+import junit.framework.Test;
+import junit.framework.TestSuite;
+import junit.textui.TestRunner;
+
 /**
  * Deployers VFS Test Suite.
  * 
@@ -83,7 +82,6 @@
       suite.addTest(MergeDeployerTestSuite.suite());
       suite.addTest(FaceletsTestSuite.suite());
       suite.addTest(ValidateDeployerTestSuite.suite());
-      suite.addTest(AnnotationScanningTestSuite.suite());
       suite.addTest(DependencyTestSuite.suite());
       suite.addTest(JMXTestSuite.suite());
       suite.addTest(WebBeansTestSuite.suite()); // now Weld

Modified: projects/jboss-deployers/trunk/deployers-vfs/src/test/java/org/jboss/test/deployers/vfs/deployer/bean/test/BeanScanningUnitTestCase.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-vfs/src/test/java/org/jboss/test/deployers/vfs/deployer/bean/test/BeanScanningUnitTestCase.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-vfs/src/test/java/org/jboss/test/deployers/vfs/deployer/bean/test/BeanScanningUnitTestCase.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -21,9 +21,6 @@
 */
 package org.jboss.test.deployers.vfs.deployer.bean.test;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
 import org.jboss.beans.metadata.api.annotations.Bean;
 import org.jboss.beans.metadata.spi.builder.BeanMetaDataBuilder;
 import org.jboss.beans.metadata.spi.factory.BeanFactory;
@@ -48,10 +45,12 @@
 import org.jboss.deployers.vfs.plugins.classloader.VFSClassLoaderDescribeDeployer;
 import org.jboss.deployers.vfs.spi.client.VFSDeployment;
 import org.jboss.kernel.Kernel;
-import org.jboss.kernel.spi.config.KernelConfigurator;
 import org.jboss.kernel.spi.dependency.KernelController;
 import org.jboss.test.deployers.vfs.deployer.AbstractDeployerUnitTest;
 
+import junit.framework.Test;
+import junit.framework.TestSuite;
+
 /**
  * BeanScanningUnitTestCase.
  *
@@ -97,9 +96,9 @@
       ClassLoaderSystem system = new DefaultClassLoaderSystem();
       // allow MC annotations and classes used by GenericBeanFactory constructor (needed for the jboss-reflect javassist
       //implementation), so that both, deployer and tester see the same
-      ClassFilter mcAnnFilter = new PackageClassFilter(new String[]{"org.jboss.beans.metadata.api.annotations", 
+      ClassFilter scanFilter = new PackageClassFilter(new String[]{"org.jboss.beans.metadata.api.annotations",
             "org.jboss.kernel.spi.config", "org.jboss.beans.metadata.spi.factory"});
-      ClassFilter filter = new CombiningClassFilter(false, new ClassFilter[]{ClassFilterUtils.JAVA_ONLY, mcAnnFilter});
+      ClassFilter filter = new CombiningClassFilter(false, new ClassFilter[]{ClassFilterUtils.JAVA_ONLY, scanFilter});
       ParentPolicy policy = new ParentPolicy(filter, ClassFilterUtils.NOTHING);
       system.getDefaultDomain().setParentPolicy(policy);
 

Modified: projects/jboss-deployers/trunk/deployers-vfs/src/test/java/org/jboss/test/deployers/vfs/structure/ear/support/MockEarStructureDeployer.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-vfs/src/test/java/org/jboss/test/deployers/vfs/structure/ear/support/MockEarStructureDeployer.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-vfs/src/test/java/org/jboss/test/deployers/vfs/structure/ear/support/MockEarStructureDeployer.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -24,11 +24,7 @@
 import java.io.IOException;
 import java.io.InputStream;
 import java.lang.annotation.Annotation;
-import java.util.ArrayList;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.Properties;
+import java.util.*;
 import java.util.jar.Attributes;
 import java.util.jar.Manifest;
 
@@ -38,7 +34,7 @@
 import org.jboss.deployers.vfs.spi.structure.CandidateAnnotationsCallback;
 import org.jboss.deployers.vfs.spi.structure.StructureContext;
 import org.jboss.logging.Logger;
-import org.jboss.mcann.AnnotationRepository;
+import org.jboss.scanning.annotations.spi.AnnotationRepository;
 import org.jboss.vfs.VFSUtils;
 import org.jboss.vfs.VirtualFile;
 import org.jboss.vfs.VirtualFileFilter;

Modified: projects/jboss-deployers/trunk/deployers-vfs-spi/pom.xml
===================================================================
--- projects/jboss-deployers/trunk/deployers-vfs-spi/pom.xml	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-vfs-spi/pom.xml	2010-05-26 15:44:09 UTC (rev 105261)
@@ -78,41 +78,73 @@
         </exclusion>
       </exclusions>
     </dependency>
+      <dependency>
+        <groupId>org.jboss.scanning</groupId>
+        <artifactId>scanning-plugins</artifactId>
+        <exclusions>
+          <exclusion>
+            <groupId>org.jboss.deployers</groupId>
+            <artifactId>jboss-deployers-spi</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.vfs</groupId>
+            <artifactId>jboss-vfs</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss</groupId>
+            <artifactId>jboss-reflect</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.man</groupId>
+            <artifactId>jboss-managed</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.man</groupId>
+            <artifactId>jboss-metatype</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.microcontainer</groupId>
+            <artifactId>jboss-kernel</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.kernel</groupId>
+            <artifactId>jboss-kernel</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.cl</groupId>
+            <artifactId>jboss-classloading</artifactId>
+          </exclusion>
+          <exclusion>
+            <groupId>org.jboss.cl</groupId>
+            <artifactId>jboss-classloading-vfs</artifactId>
+          </exclusion>
+          <exclusion>
+              <groupId>org.jboss.weld.integration</groupId>
+              <artifactId>weld-jboss-int-deployer</artifactId>
+            </exclusion>
+            <exclusion>
+              <groupId>org.jboss.mc-int</groupId>
+              <artifactId>jboss-mc-int-servlet</artifactId>
+            </exclusion>
+            <exclusion>
+              <groupId>javax.faces</groupId>
+              <artifactId>jsf-api</artifactId>
+            </exclusion>
+            <exclusion>
+              <groupId>javax.faces</groupId>
+              <artifactId>jsf-impl</artifactId>
+            </exclusion>
+            <exclusion>
+              <groupId>javassist</groupId>
+              <artifactId>javassist</artifactId>
+            </exclusion>
+            <exclusion>
+              <groupId>org.hibernate</groupId>
+              <artifactId>hibernate-entitymanager</artifactId>
+            </exclusion>
+        </exclusions>
+      </dependency>
     <dependency>
-      <groupId>org.jboss.mcann</groupId>
-      <artifactId>mcann-core</artifactId>
-      <exclusions>
-        <exclusion>
-          <groupId>org.jboss.vfs</groupId>
-          <artifactId>jboss-vfs</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss</groupId>
-          <artifactId>jboss-reflect</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.man</groupId>
-          <artifactId>jboss-managed</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.man</groupId>
-          <artifactId>jboss-metatype</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.microcontainer</groupId>
-          <artifactId>jboss-kernel</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.kernel</groupId>
-          <artifactId>jboss-kernel</artifactId>
-        </exclusion>
-        <exclusion>
-          <groupId>org.jboss.cl</groupId>
-          <artifactId>jboss-classloading</artifactId>
-        </exclusion>
-      </exclusions>
-    </dependency>
-    <dependency>
       <groupId>stax</groupId>
       <artifactId>stax-api</artifactId>
     </dependency>

Modified: projects/jboss-deployers/trunk/deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure/CandidateAnnotationsCallback.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure/CandidateAnnotationsCallback.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure/CandidateAnnotationsCallback.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -23,7 +23,7 @@
 
 import java.lang.annotation.Annotation;
 
-import org.jboss.mcann.AnnotationRepository;
+import org.jboss.scanning.annotations.spi.AnnotationRepository;
 import org.jboss.vfs.VirtualFile;
 
 /**

Modified: projects/jboss-deployers/trunk/deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure/helpers/AbstractStructureDeployer.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure/helpers/AbstractStructureDeployer.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure/helpers/AbstractStructureDeployer.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -28,18 +28,13 @@
 import java.util.List;
 import java.util.Set;
 
-import org.jboss.deployers.spi.structure.ClassPathEntry;
-import org.jboss.deployers.spi.structure.ContextInfo;
-import org.jboss.deployers.spi.structure.MetaDataEntry;
-import org.jboss.deployers.spi.structure.MetaDataType;
-import org.jboss.deployers.spi.structure.StructureMetaData;
-import org.jboss.deployers.spi.structure.StructureMetaDataFactory;
+import org.jboss.deployers.spi.structure.*;
 import org.jboss.deployers.vfs.spi.structure.CandidateAnnotationsCallback;
 import org.jboss.deployers.vfs.spi.structure.StructureContext;
 import org.jboss.deployers.vfs.spi.structure.StructureDeployer;
 import org.jboss.deployers.vfs.spi.structure.VFSStructuralDeployers;
 import org.jboss.logging.Logger;
-import org.jboss.mcann.AnnotationRepository;
+import org.jboss.scanning.annotations.spi.AnnotationRepository;
 import org.jboss.util.collection.CollectionsFactory;
 import org.jboss.vfs.VFSUtils;
 import org.jboss.vfs.VirtualFile;

Modified: projects/jboss-deployers/trunk/pom.xml
===================================================================
--- projects/jboss-deployers/trunk/pom.xml	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/pom.xml	2010-05-26 15:44:09 UTC (rev 105261)
@@ -22,13 +22,13 @@
 
   <properties>
     <version.jboss.vfs>3.0.0.CR5</version.jboss.vfs>
-    <version.jboss.reflect>2.2.0.Alpha4</version.jboss.reflect>
+    <version.jboss.reflect>2.2.0.Alpha5</version.jboss.reflect>
     <version.jboss.classpool>1.0.0.Alpha4</version.jboss.classpool>
-    <version.jboss.man>2.1.1.SP1</version.jboss.man>
-    <version.jboss.mdr>2.2.0.Alpha2</version.jboss.mdr>
+    <version.jboss.man>2.1.1.SP2</version.jboss.man>
+    <version.jboss.mdr>2.2.0.Alpha3</version.jboss.mdr>
     <version.jboss.kernel>2.2.0.Alpha10</version.jboss.kernel>
-    <version.jboss.classloader>2.2.0-SNAPSHOT</version.jboss.classloader>
-    <version.jboss.classloading.spi>5.1.0.SP1</version.jboss.classloading.spi>
+    <version.jboss.classloader>2.2.0.Alpha5</version.jboss.classloader>
+    <version.jboss.classloading.spi>6.0.0-Alpha8</version.jboss.classloading.spi>
     <version.jboss.common.core>2.2.17.GA</version.jboss.common.core>
     <version.jboss.logging.spi>2.2.0.CR1</version.jboss.logging.spi>
     <version.jboss.logging.log4j>2.2.0.CR1</version.jboss.logging.log4j>
@@ -40,7 +40,7 @@
     <version.stax.staxapi>1.0</version.stax.staxapi>
     <version.ant.junit>1.6.5</version.ant.junit>
     <version.jboss.byteman>1.0.3.CP01</version.jboss.byteman>
-    <version.jboss.mcann>1.0.0.Alpha2</version.jboss.mcann>
+    <version.jboss.mcscan>1.0.0.Alpha1</version.jboss.mcscan>
   </properties>
 
   <modules>
@@ -102,6 +102,12 @@
             <includes>
               <include>org/jboss/test/**/*TestCase.java</include>
             </includes>
+            <systemProperties>
+              <property>
+                <name>org.jboss.reflect.spi.TypeInfoFactory</name>
+                <value>org.jboss.reflect.plugins.introspection.IntrospectionTypeInfoFactory</value>
+              </property>
+            </systemProperties>
           </configuration>
         </plugin>
       </plugins>
@@ -346,10 +352,25 @@
         <version>${version.jboss.classpool}</version>
       </dependency>
       <dependency>
-          <groupId>org.jboss.mcann</groupId>
-          <artifactId>mcann-core</artifactId>
-          <version>${version.jboss.mcann}</version>
+          <groupId>org.jboss.scanning</groupId>
+          <artifactId>scanning-spi</artifactId>
+          <version>${version.jboss.mcscan}</version>
       </dependency>
+      <dependency>
+          <groupId>org.jboss.scanning</groupId>
+          <artifactId>scanning-impl</artifactId>
+          <version>${version.jboss.mcscan}</version>
+      </dependency>
+      <dependency>
+          <groupId>org.jboss.scanning</groupId>
+          <artifactId>scanning-plugins</artifactId>
+          <version>${version.jboss.mcscan}</version>
+      </dependency>
+      <dependency>
+          <groupId>org.jboss.scanning</groupId>
+          <artifactId>scanning-deployers</artifactId>
+          <version>${version.jboss.mcscan}</version>
+      </dependency>
       <!-- test dependencies -->
       <dependency>
         <groupId>org.jboss.test</groupId>




More information about the jboss-cvs-commits mailing list
--- projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/annotations/AnnotationRepositoryDeployer.java	2010-05-26 15:18:17 UTC (rev 105260)
+++ projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/annotations/AnnotationRepositoryDeployer.java	2010-05-26 15:44:09 UTC (rev 105261)
@@ -31,22 +31,19 @@
 import org.jboss.deployers.vfs.spi.deployer.AbstractOptionalVFSRealDeployer;
 import org.jboss.deployers.vfs.spi.structure.VFSDeploymentUnit;
 import org.jboss.deployers.vfs.spi.structure.VFSDeploymentUnitFilter;
-import org.jboss.mcann.AnnotationRepository;
-import org.jboss.mcann.repository.Configuration;
-import org.jboss.mcann.repository.DefaultConfiguration;
-import org.jboss.mcann.repository.AbstractSettings;
-import org.jboss.mcann.repository.AbstractConfiguration;
-import org.jboss.mcann.scanner.DefaultAnnotationScanner;
-import org.jboss.mcann.scanner.ModuleAnnotationScanner;
+import org.jboss.scanning.annotations.plugins.AnnotationsScanningPlugin;
+import org.jboss.scanning.annotations.spi.AnnotationRepository;
+import org.jboss.scanning.plugins.DeploymentUnitScanner;
+import org.jboss.scanning.spi.helpers.AbstractScanner;
 
 /**
  * A POST_CLASSLOADER deployer which creates AnnotationRepository for sub-deployments.
  *
  * @author <a href="mailto:ales.justin at jboss.com">Ales Justin</a>
  */
+ at Deprecated
 public class AnnotationRepositoryDeployer extends AbstractOptionalVFSRealDeployer<Module>
 {
-   private Configuration configuration;
    private VFSDeploymentUnitFilter filter;
 
    public AnnotationRepositoryDeployer()
@@ -59,16 +56,6 @@
    }
 
    /**
-    * Set configuration.
-    *
-    * @param configuration the configuration
-    */
-   public void setConfiguration(Configuration configuration)
-   {
-      this.configuration = configuration;
-   }
-
-   /**
     * Set vfs deployment filter.
     *
     * @param filter the vfs deployment filter.
@@ -85,23 +72,19 @@
     * before we visit it.
     *
     * @param unit the deployment unit
-    * @param module the module
     * @throws DeploymentException for any error
     */
-   protected void visitModule(VFSDeploymentUnit unit, Module module) throws DeploymentException
+   protected void visitModule(VFSDeploymentUnit unit) throws DeploymentException
    {
       try
       {
          URL[] urls = ClasspathUtils.getUrls(unit);
-         DefaultAnnotationScanner scanner = new ModuleAnnotationScanner(module);
+         AbstractScanner scanner = new DeploymentUnitScanner(unit, urls);
+         AnnotationsScanningPlugin plugin = createPlugin(unit);
 
-         AbstractConfiguration config = new DefaultConfiguration();
-         configureScanner(unit, scanner, config);
-         if (configuration != null)
-            config.merge(configuration); // override with custom config
-         scanner.setConfiguration(config);
+         scanner.scan();
 
-         AnnotationRepository repository = scanner.scan(unit.getClassLoader(), urls);
+         AnnotationRepository repository = unit.getAttachment(plugin.getAttachmentKey(), AnnotationRepository.class);
          unit.addAttachment(AnnotationRepository.class, repository);
       }
       catch (Exception e)
@@ -110,25 +93,29 @@
       }
    }
 
-   protected AbstractConfiguration createConfiguration(VFSDeploymentUnit unit)
+   /**
+    * Configure scanner and plugin.
+    *
+    * @param scanner the annotation scanner
+    */
+   protected void configureScanner(DeploymentUnitScanner scanner)
    {
-      return new DefaultConfiguration();
    }
 
    /**
-    * Configure scanner.
+    * Create and configure annotation plugin.
     *
     * @param unit the deployment unit
-    * @param scanner the annotation scanner
-    * @param settings the settings
+    * @return new annotation plugin
     */
-   protected void configureScanner(VFSDeploymentUnit unit, DefaultAnnotationScanner scanner, AbstractSettings settings)
+   protected AnnotationsScanningPlugin createPlugin(VFSDeploymentUnit unit)
    {
+      return new AnnotationsScanningPlugin(unit.getClassLoader());
    }
 
    public void deploy(VFSDeploymentUnit unit, Module module) throws DeploymentException
    {
       // we already used McAnn or some other mechanism to create repo
       if (unit.isAttachmentPresent(AnnotationRepository.class))
          return;
 
@@ -136,21 +123,9 @@
       if (filter != null && filter.accepts(unit) == false)
          return;
 
-      if (module == null)
-      {
-         VFSDeploymentUnit parent = unit.getParent();
-         while(parent != null && module == null)
-         {
-            module = parent.getAttachment(Module.class);
-            parent = parent.getParent();
-         }
-         if (module == null)
-            throw new IllegalArgumentException("No module in deployment unit's hierarchy: " + unit.getName());
-      }
-
       if (log.isTraceEnabled())
-         log.trace("Creating AnnotationRepository for " + unit.getName() + ", module: " + module + ", configuration: " + configuration);
+         log.trace("Creating AnnotationRepository for " + unit.getName() + ", module: " + module);
 
-      visitModule(unit, module);
+      visitModule(unit);
    }
 }
@@ -110,25 +93,29 @@
    public void deploy(VFSDeploymentUnit unit, Module module) throws DeploymentException
    {
-      // we already used McAnn or some other mechanism to create repo
+      // we already used mc scanning or some other mechanism to create repo
       if (unit.isAttachmentPresent(AnnotationRepository.class))
          return;

Modified: projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/annotations/FilteredAnnotationRepositoryDeployer.java
===================================================================